#!/bin/sh
# Channel editor script

[ -x /opt/sbin/flash_unlock ] || exit 0
[ -x /opt/bin/channels ] || exit 0
[ -x /opt/sbin/flashcp ] || exit 0
[ -x /opt/bin/busybox/busybox ] || exit 0

# Create channel location if not available
[ -d /opt/channels ] || mkdir -m 777 -p /opt/channels >/dev/null 2>&1
[ -L /media/Channels ] || ln -s /opt/channels /media/Channels

# Create New Backup file (New install).
if [ ! -f /opt/channels/FOXSAT-HDR_channels_backup.fcl ]
then
	# Use the channels utility to create a copy of /dev/mtd6 with hidden and freesat flags
	# reset to default values.  This is the expected default position for this file as normally
	# it will contain a copy of /dev/mtd6 after housekeeping
	/opt/bin/channels reset_all -f /dev/mtd6 -c /opt/channels/FOXSAT-HDR_channels_backup.fcl
	
	# Import the default channel settings into the channels database ready for the Web Interface
	# to use
	/opt/bin/channels readall -f /opt/channels/FOXSAT-HDR_channels_backup.fcl -b TBL_SVC_DEFAULT
fi

# This script is structured to avoid the case where Humax is in standby for days 
# on end and therefore only ever boots at 3am for housekeeping.  In this event 
# we could get the circumstance that it's a Housekeeping boot AND the Housekeeping flag is set from 
# the previous boot.  We need to avoid this.

# Assume that the sysclock utility has been run before we get here therefore the
# clock will already be set
if [ -f /opt/etc/HouseKeeper ]
then
	# This is the Housekeeping boot (and settop hasn't started) so reset the non-freesat
	# channels marked as freesat otherwise housekeeping will delete them.
	# Nothing else will be done on this boot.
	/opt/bin/channels reset_all -f /dev/mtd6
	
else

	if [ -f /opt/etc/FirstBoot ]
	# This is the first (non 3am) boot after housekeeping
	then
		# Create new backup file.
		cat /dev/mtd6 > /opt/channels/FOXSAT-HDR_channels_backup.fcl
		
		# First boot after housekeeping so create a new update file.  Use the backup file
		# created above as a base since this contains the mtd6 data as Humax housekeeping  
		# left it.  Apply changes specified by the WebIf channel editor and saved to 
		# the /opt/epg/channels.db database
		/opt/bin/channels update -f /opt/channels/FOXSAT-HDR_channels_backup.fcl -c /opt/channels/FOXSAT-HDR_channels_update.fcl
		
		touch -r /opt/etc/LastHK /opt/channels/FOXSAT-HDR_channels_backup.fcl

	
		# Apply the update
		if [ -f /opt/channels/FOXSAT-HDR_channels_update.fcl ]
		then
			/opt/sbin/flash_unlock /dev/mtd6
			/opt/sbin/flashcp /opt/channels/FOXSAT-HDR_channels_update.fcl /dev/mtd6
			# flag update as applied
			touch -d "2000-01-01 01:00:00" /opt/channels/FOXSAT-HDR_channels_update.fcl
		fi

	elif [ -f /opt/channels/FOXSAT-HDR_channels_update.fcl ]
	then
		# An update.fcl file existis
		if [ `date -r /opt/channels/FOXSAT-HDR_channels_update.fcl "+%Y"` != "2000" ]
		then
			# And it hasn't previously been applied so apply it
			/opt/sbin/flash_unlock /dev/mtd6
			/opt/sbin/flashcp /opt/channels/FOXSAT-HDR_channels_update.fcl /dev/mtd6
			# flag update as applied
			touch -d "2000-01-01 01:00:00" /opt/channels/FOXSAT-HDR_channels_update.fcl
		fi
	fi
	
	# On all non-housekeeping boot cycles, load the backup.fcl file into the channels database
	# as the "Default" settings.  Will be used by the WebIf Channel Editor Screen
	if [ -f /opt/channels/FOXSAT-HDR_channels_backup.fcl ]
	then
		/opt/bin/channels readall -f /opt/channels/FOXSAT-HDR_channels_backup.fcl -b TBL_SVC_DEFAULT
	else
		# No Backup file so populate the defaults with the current 
		# /dev/mtd6 settings.  NOTE: This should never happen!!!!
		/opt/bin/channels readall -f /dev/mtd6 -b TBL_SVC_DEFAULT
	fi
fi

